Crate typst_kit

Crate typst_kit 

Typst Kit contains useful building blocks for Typst integrations. It is intended as a single source of truth for things like font searching, package loading and more. In particular, it contains various implementations of functionality used in typst-cli.

Features flags

Crate functionality that incurs additional dependencies is heavily feature-flagged, so that you can pick exactly what you need. By default, all features are disabled. The available feature flags are:

Modules

datetimedatetime
Date and time manipulation.
diagnosticsemit-diagnostics
Diagnostic pretty-printing.
downloader
Web requests with optional progress reporting.
files
File loading and management.
fonts
Font loading and management.
packages
Package loading.
serverhttp-server
A minimal hot-reloading HTTP server.
timertimer
Recording and writing of performance timing files.
watcherwatcher
File system watching.