pub struct Time(/* private fields */);Available on crate feature
datetime only.Expand description
The current date and time.
Implementations
Sourceimpl Time
impl Time
Sourcepub fn fixed(datetime: Datetime) -> StrResult<Self>
pub fn fixed(datetime: Datetime) -> StrResult<Self>
Use a predefined fixed date and time to provide the current date. Used for reproducible builds.
Returns an error if datetime is only a time.
Sourcepub fn fixed_timestamp(timestamp: i64) -> StrResult<Self>
pub fn fixed_timestamp(timestamp: i64) -> StrResult<Self>
Use a fixed timestamp to provide the current date. Used for reproducible builds.
This timestamp is usually provided using the SOURCE_DATE_EPOCH
environment variable.
Returns an error if the timestamp is out of range.