File loading and management.
Structs
- File
Store - Holds loaded files and sources.
- FsRoot
- A root that is backed by a file system directory.
- System
Files system-files - Serves project files from a directory and package files from standard locations.
Traits
- File
Loader - Provides data for files, backing a
FileStore.