pub struct FsRoot(/* private fields */);Expand description
A root that is backed by a file system directory.
A Typst project forms a root. Similarly, each package has its own root. Through this mechanism, projects and packages are isolated from each other.
Implementations
Sourceimpl FsRoot
impl FsRoot
Sourcepub fn resolve(&self, path: &VirtualPath) -> PathBuf
pub fn resolve(&self, path: &VirtualPath) -> PathBuf
Resolves the real file system path for the given virtual path in this root.
Sourcepub fn load(&self, path: &VirtualPath) -> FileResult<Bytes>
pub fn load(&self, path: &VirtualPath) -> FileResult<Bytes>
Loads file data from the given virtual path in this root.