pub struct SystemFiles { /* private fields */ }Available on crate feature
system-files only.Expand description
Serves project files from a directory and package files from standard locations.
With this implementation,
- project files are loaded from a project root directory through an
FsRoot. - package files are loaded from configured directories and/or the official
Typst Universe package registry via
SystemPackages.
Implementations
Sourceimpl SystemFiles
impl SystemFiles
Sourcepub fn new(project: FsRoot, packages: SystemPackages) -> Self
pub fn new(project: FsRoot, packages: SystemPackages) -> Self
Creates a new instance with a given file system root for project files and the given configuration for system packages.
Sourcepub fn resolve(&self, id: FileId) -> FileResult<PathBuf>
pub fn resolve(&self, id: FileId) -> FileResult<PathBuf>
Resolves the path of the given file id in the file system.
Sourcepub fn root(&self, id: FileId) -> FileResult<FsRoot>
pub fn root(&self, id: FileId) -> FileResult<FsRoot>
Resolves the root in which the given file ID resides.