pub struct FontStore { /* private fields */ }Expand description
Holds loaded fonts.
Fonts can be added with push and extend.
The three top-level font provider functions in this module can directly be
used with FontStore::extend.
Font are added in-order. The indices in the font book and those that should
be passed to source and source match this
order.
Implementations
Sourceimpl FontStore
impl FontStore
Sourcepub fn push(&mut self, entry: (impl FontSource, FontInfo))
pub fn push(&mut self, entry: (impl FontSource, FontInfo))
Adds a new entry to the store.
Sourcepub fn extend<T>(&mut self, entries: impl IntoIterator<Item = (T, FontInfo)>)where
T: FontSource,
pub fn extend<T>(&mut self, entries: impl IntoIterator<Item = (T, FontInfo)>)where
T: FontSource,
Adds multiple new entries to the store.
Sourcepub fn book(&self) -> &LazyHash<FontBook>
pub fn book(&self) -> &LazyHash<FontBook>
Provides metadata for the added fonts.
Can directly be used to implement
World::book.
Sourcepub fn font(&self, index: usize) -> Option<Font>
pub fn font(&self, index: usize) -> Option<Font>
Retrieves the font at the given index.
Loads the font if it’s not already loaded.
Can directly be used to implement
World::font.
Sourcepub fn source(&self, index: usize) -> Option<&dyn FontSource>
pub fn source(&self, index: usize) -> Option<&dyn FontSource>
Retrieves the underlying font source for the font with this index.