FsPackages

Struct FsPackages 

pub struct FsPackages(/* private fields */);
Serves packages from a well-structured directory on the file system.

This directory should be structured as follows:

  • Top-level directories denote namespaces
  • Second-level directories denote packages
  • Third-level directories denote package versions

Implementations

Source

impl FsPackages

pub fn new(path: impl Into<PathBuf>) -> Self

Creates a new handle that serves packages from the given directory.

pub fn system_data() -> Option<FsPackages>

Available on crate feature system-packages only.

Tries to provide a handle to the environment-defined standard system package data directory.

This is:

  • $XDG_DATA_HOME/typst/packages or ~/.local/share/typst/packages on Linux
  • ~/Library/Application Support/typst/packages on macOS
  • %APPDATA%/typst/packages on Windows
pub fn system_cache() -> Option<FsPackages>

Available on crate feature system-packages only.

Tries to provide a handle to the environment-defined standard system package cache directory.

This is:

  • $XDG_CACHE_HOME/typst/packages or ~/.cache/typst/packages on Linux
  • ~/Library/Caches/typst/packages on macOS
  • %LOCALAPPDATA%/typst/packages on Windows
pub fn path(&self) -> &Path

Returns the path from which this serves packages.

pub fn obtain(&self, spec: &PackageSpec) -> Option<FsRoot>

Returns the file system root from which the given package’s content can be loaded.

pub fn latest_version( &self, spec: &VersionlessPackageSpec, ) -> Option<PackageVersion>

Tries to determine the latest version of a particular package in the directory tree.

pub fn store( &self, spec: &PackageSpec, write: impl FnOnce(&Path) -> PackageResult<()>, ) -> PackageResult<()>

Available on crate feature universe-packages only.

Stores data for the given package in the package directory by invoking write on a target path. The package contents should be written relative to the path passed to write.

Internally, this function ensures that concurrent access to the package directory is safe. From two concurrent stores, it is not specified which one wins, but they will not infer or result in partial / corrupted package contents.