pub struct SystemPackages { /* private fields */ }system-packages only.Expand description
Serves packages from standard locations.
In order of priority, this tries to obtain a package from
- a package data directory (that is intended for system-wide storage of user packages)
- a package cache directory (that is intended for caching of automatically downloaded packages)
- by downloading it from Typst Universe or a mirror of it (if it’s namespace matches the one Typst Universe serves)
With default configuration, this loads packages from the same sources as the CLI.
Implementations
Sourceimpl SystemPackages
impl SystemPackages
Sourcepub fn new(downloader: impl Downloader) -> Self
pub fn new(downloader: impl Downloader) -> Self
Creates a new handle that serves packages from standard environment-defined directories and the official Typst Universe registry.
- See
FsPackagesfor more details on the default directories. - See
UniversePackagesfor more details on the registry.
This loads packages from the same sources as the CLI in its default configuration.
Sourcepub fn from_parts(
data: Option<FsPackages>,
cache: Option<FsPackages>,
universe: UniversePackages,
) -> Self
pub fn from_parts( data: Option<FsPackages>, cache: Option<FsPackages>, universe: UniversePackages, ) -> Self
Creates a new system package loader from custom configured parts.
Sourcepub fn data(&self) -> Option<&FsPackages>
pub fn data(&self) -> Option<&FsPackages>
Returns a handle to the data package directory.
Sourcepub fn cache(&self) -> Option<&FsPackages>
pub fn cache(&self) -> Option<&FsPackages>
Returns a handle to the cache package directory.
Sourcepub fn universe(&self) -> &UniversePackages
pub fn universe(&self) -> &UniversePackages
Returns a handle to the Typst universe registry.
Sourcepub fn obtain(&self, spec: &PackageSpec) -> PackageResult<FsRoot>
pub fn obtain(&self, spec: &PackageSpec) -> PackageResult<FsRoot>
Returns the file system root from which the given package’s content can be loaded.
May download the package from the network if it’s not already available. Downloads are retained in the configured cache directory. As such, this function can have a file system side effect.
Concurrent downloads do not cause corruption, but for the purpose of
efficiency, it may be desirable to avoid them. If you use the
FileStore, this is already the case since
it acquires a lock during file loading.
Sourcepub fn latest_version(
&self,
spec: &VersionlessPackageSpec,
) -> StrResult<PackageVersion>
pub fn latest_version( &self, spec: &VersionlessPackageSpec, ) -> StrResult<PackageVersion>
Tries to determine the latest version of a package.