UniversePackages

Struct UniversePackages 

pub struct UniversePackages { /* private fields */ }
Available on crate feature universe-packages only.
Serves packages from the Typst Universe registry.

There is no standardized registry protocol. This is merely designed to work with the official Typst Universe package registry.

Implementations

Source

impl UniversePackages

pub const NAMESPACE: &str = "preview"

The namespace from which Typst Universe serves packages.

pub fn new(downloader: impl Downloader) -> Self

Creates a new handle for interacting with the primary official registry at https://packages.typst.org.

pub fn with_url(downloader: impl Downloader, url: impl Into<String>) -> Self

Creates a new handle which serves packages from an alternative mirror.

pub fn url(&self) -> &str

Returns the registry’s URL.

pub fn package( &self, spec: &PackageSpec, ) -> PackageResult<Archive<impl Read + use<>>>

Attempts to download a package from the registry.

Will invoke the downloader with the spec as the key.

pub fn latest_version( &self, spec: &VersionlessPackageSpec, ) -> StrResult<PackageVersion>

Attempts to determine the latest version of a package.

Will invoke the downloader with the key "package index".