pub struct Timer { /* private fields */ }Available on crate feature
timer only.Expand description
Allows to record timings of function executions.
Implementations
Sourceimpl Timer
impl Timer
Sourcepub fn new(path: PathBuf) -> Self
pub fn new(path: PathBuf) -> Self
Creates a timer that can be used to record timings for a specific function invocation.
Will also internally enable event collection in typst_timing.
If the path contains the string {n}, it is replaced with a per
recording index. If recording multiple events, the path must contain
this string.
Sourcepub fn placeholder() -> Self
pub fn placeholder() -> Self
Returns a placeholder that does not record any actual timings. This can
be useful to have uniform code paths with timer.record regardless of
whether timings are enabled at runtime.
Sourcepub fn new_or_placeholder(path: Option<PathBuf>) -> Self
pub fn new_or_placeholder(path: Option<PathBuf>) -> Self
Creates a proper timer if the path is Some(_) or a placeholder timer
if the path is None.