Typst Kit contains useful building blocks for Typst integrations. It is
intended as a single source of truth for things like font searching, package
loading and more. In particular, it contains various implementations of
functionality used in typst-cli.
Features flags
Crate functionality that incurs additional dependencies is heavily feature-flagged, so that you can pick exactly what you need. By default, all features are disabled. The available feature flags are:
bundle: Enables functionality related totypst_bundle.embedded-fonts: Enables loading of embedded fonts viafonts::embedded.scan-fonts: Enables font discovery at paths and from the system viafonts::scanandfonts::system.system-files: Enables loading of files from standard locations viafiles::SystemFiles.system-packages: Enables loading of packages from standard locations viapackages::SystemPackages.universe-packages: Enables loading of packages from Typst Universe viapackages::UniversePackages.emit-diagnostics: Enables emitting terminal-style diagnostics viadatetime: Enables obtaining the current date viadatetime::Time::today.diagnostics::emit.system-downloader: Enables network requests viadownloader::SystemDownloader.watcher: Enables file system watching viawatcher::Watcher.timer: Enables performance tracing viatimer::Timer.http-server: Enables a live-reloading HTTP serving viaserver::HttpServer.vendor-openssl: Whether to vendor OpenSSL for thesystem-downloader. Not applicable to Windows and macOS build.
Modules
- datetime
datetime - Date and time manipulation.
- diagnostics
emit-diagnostics - Diagnostic pretty-printing.
- downloader
- Web requests with optional progress reporting.
- files
- File loading and management.
- fonts
- Font loading and management.
- packages
- Package loading.
- server
http-server - A minimal hot-reloading HTTP server.
- timer
timer - Recording and writing of performance timing files.
- watcher
watcher - File system watching.