Web requests with optional progress reporting.
All typst-kit functionality that may trigger downloads goes through the
Downloader trait. A built-in implementation is provided through the
SystemDownloader.
Downloads can optionally be tracked by wrapping an existing downloader in a
ProgressDownloader. All downloads are identified by a dynamic key, so
that the progress downloader’s underlying Progress reporter can decide
whether it wants to display something.
Structs
- Progress
- The current progress of a download.
- Progress
Downloader - Wraps a downloader and adds progress reporting to it.
- System
Downloader system-downloader - A minimal HTTPS client for downloads.
Traits
- Downloader
- Downloads resources from the network.
- Progress
Reporter - Manages progress reporting for downloads.