pub struct FileStore<L> { /* private fields */ }Expand description
Holds loaded files and sources.
This type is backed by a file loader of your choosing. Internally, it
handles caching of loaded files and creation of Typst sources.
This is the right level of abstraction if you’re building a Typst
integration that’s concerned with providing input bytes on-demand, but does
not require tighter integration with Typst Sources. It is
appropriate for most clients.
If you need more control, you can skip this and implement custom logic that
directly handles the World::source and
World::file requests. A language server is
an example of an integration that might want to go even deeper, to create,
manage, and edit source files by itself. If you go the manual route, ensure
that those methods are cheap on repeated calls (either through caching or by
virtue of always being cheap).
Implementations
Sourceimpl<L> FileStore<L>where
L: FileLoader,
impl<L> FileStore<L>where
L: FileLoader,
Sourcepub fn new(loader: L) -> Self
pub fn new(loader: L) -> Self
Creates a new file store that loads file data via the provided loader.
Sourcepub fn loader_mut(&mut self) -> &mut L
pub fn loader_mut(&mut self) -> &mut L
Returns a mutable reference to the underlying loader.
Sourcepub fn into_loader(self) -> L
pub fn into_loader(self) -> L
Drops the store, extracting the underlying loader.
Sourcepub fn source(&self, id: FileId) -> FileResult<Source>
pub fn source(&self, id: FileId) -> FileResult<Source>
Retrieves the given file id as a Typst source.
Can directly be used to implement
World::source.
Sourcepub fn file(&self, id: FileId) -> FileResult<Bytes>
pub fn file(&self, id: FileId) -> FileResult<Bytes>
Retrieves the given file id as a raw file.
Can directly be used to implement
World::file.
Sourcepub fn dependencies(&mut self) -> (&L, impl Iterator<Item = FileId> + '_)
pub fn dependencies(&mut self) -> (&L, impl Iterator<Item = FileId> + '_)
Returns all files that were referenced since the last
reset().
Also returns a reference to the loader so that the IDs can be resolved
with it. It couldn’t be accessed through .loader()
while iterating because of overlapping borrows.
The dependencies are returned in arbitrary order! If you want to get a consistent result, you should sort them by a suitable criterion after the fact.
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Resets the store.
This marks all loaded file as stale. On subsequent accesses, they will
be loaded once more through the underlying loader. Moreover, calls to
dependencies() will not yield files accessed
before the call to reset().
Unlike when creating an entirely new store, source files will be edited in place with updated data, leading to improved incremental compilation performance.