pub struct FsPackages(/* private fields */);Expand description
Serves packages from a well-structured directory on the file system.
This directory should be structured as follows:
- Top-level directories denote namespaces
- Second-level directories denote packages
- Third-level directories denote package versions
Implementations
Sourceimpl FsPackages
impl FsPackages
Sourcepub fn new(path: impl Into<PathBuf>) -> Self
pub fn new(path: impl Into<PathBuf>) -> Self
Creates a new handle that serves packages from the given directory.
Sourcepub fn system_data() -> Option<FsPackages>
Available on crate feature system-packages only.
pub fn system_data() -> Option<FsPackages>
system-packages only.Tries to provide a handle to the environment-defined standard system package data directory.
This is:
$XDG_DATA_HOME/typst/packagesor~/.local/share/typst/packageson Linux~/Library/Application Support/typst/packageson macOS%APPDATA%/typst/packageson Windows
Sourcepub fn system_cache() -> Option<FsPackages>
Available on crate feature system-packages only.
pub fn system_cache() -> Option<FsPackages>
system-packages only.Tries to provide a handle to the environment-defined standard system package cache directory.
This is:
$XDG_CACHE_HOME/typst/packagesor~/.cache/typst/packageson Linux~/Library/Caches/typst/packageson macOS%LOCALAPPDATA%/typst/packageson Windows
Sourcepub fn obtain(&self, spec: &PackageSpec) -> Option<FsRoot>
pub fn obtain(&self, spec: &PackageSpec) -> Option<FsRoot>
Returns the file system root from which the given package’s content can be loaded.
Sourcepub fn latest_version(
&self,
spec: &VersionlessPackageSpec,
) -> Option<PackageVersion>
pub fn latest_version( &self, spec: &VersionlessPackageSpec, ) -> Option<PackageVersion>
Tries to determine the latest version of a particular package in the directory tree.
Sourcepub fn store(
&self,
spec: &PackageSpec,
write: impl FnOnce(&Path) -> PackageResult<()>,
) -> PackageResult<()>
Available on crate feature universe-packages only.
pub fn store( &self, spec: &PackageSpec, write: impl FnOnce(&Path) -> PackageResult<()>, ) -> PackageResult<()>
universe-packages only.Stores data for the given package in the package directory by invoking
write on a target path. The package contents should be written
relative to the path passed to write.
Internally, this function ensures that concurrent access to the package directory is safe. From two concurrent stores, it is not specified which one wins, but they will not infer or result in partial / corrupted package contents.