pub struct UniversePackages { /* private fields */ }Available on crate feature
universe-packages only.Expand description
Serves packages from the Typst Universe registry.
There is no standardized registry protocol. This is merely designed to work with the official Typst Universe package registry.
Implementations
Sourceimpl UniversePackages
impl UniversePackages
Sourcepub fn new(downloader: impl Downloader) -> Self
pub fn new(downloader: impl Downloader) -> Self
Creates a new handle for interacting with the primary official registry
at https://packages.typst.org.
Sourcepub fn with_url(downloader: impl Downloader, url: impl Into<String>) -> Self
pub fn with_url(downloader: impl Downloader, url: impl Into<String>) -> Self
Creates a new handle which serves packages from an alternative mirror.
Sourcepub fn package(
&self,
spec: &PackageSpec,
) -> PackageResult<Archive<impl Read + use<>>>
pub fn package( &self, spec: &PackageSpec, ) -> PackageResult<Archive<impl Read + use<>>>
Attempts to download a package from the registry.
Will invoke the downloader with the spec as the key.
Sourcepub fn latest_version(
&self,
spec: &VersionlessPackageSpec,
) -> StrResult<PackageVersion>
pub fn latest_version( &self, spec: &VersionlessPackageSpec, ) -> StrResult<PackageVersion>
Attempts to determine the latest version of a package.
Will invoke the downloader with the key "package index".